<?php

namespace App\Http\Controllers;

use App\Customer;
use App\CustomField;
use App\Mail\UserCreate;
use App\Plan;
use App\Transaction;
use Auth;
use File;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Spatie\Permission\Models\Role;

class CustomerController extends Controller
{

    public function dashboard()
    {
        $data['invoiceChartData'] = \Auth::user()->invoiceChartData();

        return view('customer.dashboard', $data);
    }

    public function index()
    {
        if(\Auth::user()->can('manage customer'))
        {
            $customers = Customer::where('created_by', \Auth::user()->creatorId())->get();

            return view('customer.index', compact('customers'));
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }

    public function create()
    {
        if(\Auth::user()->can('create customer'))
        {
            $customFields = CustomField::where('module', '=', 'customer')->get();

            return view('customer.create', compact('customFields'));
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }


    public function store(Request $request)
    {
        if(\Auth::user()->can('create customer'))
        {

            $rules = [
                'name' => 'required',
                'contact' => 'required|regex:/^([0-9\s\-\+\(\)]*)$/',
                'email' => 'required|email|unique:customers',
                'password' => 'required',
                'billing_name' => 'required',
                'billing_country' => 'required',
                'billing_state' => 'required',
                'billing_city' => 'required',
                'billing_phone' => 'required|regex:/^([0-9\s\-\+\(\)]*)$/',
                'billing_zip' => 'required',
                'billing_address' => 'required',
                'shipping_name' => 'required',
                'shipping_country' => 'required',
                'shipping_state' => 'required',
                'shipping_city' => 'required',
                'shipping_phone' => 'required|regex:/^([0-9\s\-\+\(\)]*)$/',
                'shipping_zip' => 'required',
                'shipping_address' => 'required',
            ];

            $validator = \Validator::make($request->all(), $rules);

            if($validator->fails())
            {
                $messages = $validator->getMessageBag();

                return redirect()->route('customer.index')->with('error', $messages->first());
            }

            $objCustomer    = \Auth::user();
            $total_customer = $objCustomer->countCustomers();
            $plan           = Plan::find($objCustomer->plan);
            if($total_customer < $plan->max_customers || $plan->max_customers == -1)
            {
                $customer                   = new Customer();
                $customer->customer_id      = $this->customerNumber();
                $customer->name             = $request->name;
                $customer->contact          = $request->contact;
                $customer->email            = $request->email;
                $customer->password         = Hash::make($request->password);
                $customer->created_by       = \Auth::user()->creatorId();
                $customer->billing_name     = $request->billing_name;
                $customer->billing_country  = $request->billing_country;
                $customer->billing_state    = $request->billing_state;
                $customer->billing_city     = $request->billing_city;
                $customer->billing_phone    = $request->billing_phone;
                $customer->billing_zip      = $request->billing_zip;
                $customer->billing_address  = $request->billing_address;
                $customer->shipping_name    = $request->shipping_name;
                $customer->shipping_country = $request->shipping_country;
                $customer->shipping_state   = $request->shipping_state;
                $customer->shipping_city    = $request->shipping_city;
                $customer->shipping_phone   = $request->shipping_phone;
                $customer->shipping_zip     = $request->shipping_zip;
                $customer->shipping_address = $request->shipping_address;
                $customer->save();
                CustomField::saveData($customer, $request->customField);
            }
            else
            {
                return redirect()->back()->with('error', __('Your user limit is over, Please upgrade plan.'));
            }


            $role_r = Role::where('name', '=', 'customer')->firstOrFail();
            $customer->assignRole($role_r);

            $customer->password = $request->password;
            $customer->type     = 'Customer';
            try
            {
                Mail::to($customer->email)->send(new UserCreate($customer));
            }
            catch(\Exception $e)
            {
                $smtp_error = __('E-Mail has been not sent due to SMTP configuration');
            }

            return redirect()->route('customer.index')->with('success', __('Customer successfully created.') . ((isset($smtp_error)) ? '<br> <span class="text-danger">' . $smtp_error . '</span>' : ''));
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }


    public function show($id)
    {
        $customer = Customer::find($id);

        return view('customer.show', compact('customer'));
    }


    public function edit($id)
    {
        if(\Auth::user()->can('edit customer'))
        {
            $customer              = Customer::find($id);
            $customer->customField = CustomField::getData($customer, 'customer');

            $customFields = CustomField::where('module', '=', 'customer')->get();

            return view('customer.edit', compact('customer', 'customFields'));
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }


    public function update(Request $request, Customer $customer)
    {

        if(\Auth::user()->can('edit customer'))
        {

            $rules = [
                'name' => 'required',
                'contact' => 'required|regex:/^([0-9\s\-\+\(\)]*)$/',
                'billing_name' => 'required',
                'billing_country' => 'required',
                'billing_state' => 'required',
                'billing_city' => 'required',
                'billing_phone' => 'required|regex:/^([0-9\s\-\+\(\)]*)$/',
                'billing_zip' => 'required',
                'billing_address' => 'required',
                'shipping_name' => 'required',
                'shipping_country' => 'required',
                'shipping_state' => 'required',
                'shipping_city' => 'required',
                'shipping_phone' => 'required|regex:/^([0-9\s\-\+\(\)]*)$/',
                'shipping_zip' => 'required',
                'shipping_address' => 'required',
            ];

            $validator = \Validator::make($request->all(), $rules);

            if($validator->fails())
            {
                $messages = $validator->getMessageBag();

                return redirect()->route('customer.index')->with('error', $messages->first());
            }

            $customer->name             = $request->name;
            $customer->contact          = $request->contact;
            $customer->created_by       = \Auth::user()->creatorId();
            $customer->billing_name     = $request->billing_name;
            $customer->billing_country  = $request->billing_country;
            $customer->billing_state    = $request->billing_state;
            $customer->billing_city     = $request->billing_city;
            $customer->billing_phone    = $request->billing_phone;
            $customer->billing_zip      = $request->billing_zip;
            $customer->billing_address  = $request->billing_address;
            $customer->shipping_name    = $request->shipping_name;
            $customer->shipping_country = $request->shipping_country;
            $customer->shipping_state   = $request->shipping_state;
            $customer->shipping_city    = $request->shipping_city;
            $customer->shipping_phone   = $request->shipping_phone;
            $customer->shipping_zip     = $request->shipping_zip;
            $customer->shipping_address = $request->shipping_address;
            $customer->save();

            CustomField::saveData($customer, $request->customField);

            return redirect()->route('customer.index')->with('success', __('Customer successfully updated.'));
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }


    public function destroy(Customer $customer)
    {
        if(\Auth::user()->can('delete customer'))
        {
            if($customer->created_by == \Auth::user()->creatorId())
            {
                $customer->delete();

                return redirect()->route('customer.index')->with('success', __('Customer successfully deleted.'));
            }
            else
            {
                return redirect()->back()->with('error', __('Permission denied.'));
            }
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }

    function customerNumber()
    {
        $latest = Customer::where('created_by', '=', \Auth::user()->creatorId())->latest()->first();
        if(!$latest)
        {
            return 1;
        }

        return $latest->customer_id + 1;
    }

    public function customerLogout(Request $request)
    {
        \Auth::guard('customer')->logout();

        $request->session()->invalidate();

        return redirect()->route('customer.login');
    }

    public function payment(Request $request)
    {

        if(\Auth::user()->can('manage customer payment'))
        {
            $category = [
                'Invoice' => 'Invoice',
                'Deposit' => 'Deposit',
                'Sales' => 'Sales',
            ];

            $query = Transaction::where('user_id', \Auth::user()->id)->where('user_type', 'Customer')->where('type', 'Payment');
            if(!empty($request->date))
            {
                $date_range = explode(' - ', $request->date);
                $query->whereBetween('date', $date_range);
            }

            if(!empty($request->category))
            {
                $query->where('category', '=', $request->category);
            }
            $payments = $query->get();

            return view('customer.payment', compact('payments', 'category'));
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }

    public function transaction(Request $request)
    {

        if(\Auth::user()->can('manage customer payment'))
        {

            $category = [
                'Invoice' => 'Invoice',
                'Deposit' => 'Deposit',
                'Sales' => 'Sales',
            ];

            $query = Transaction::where('user_id', \Auth::user()->id)->where('user_type', 'Customer');

            if(!empty($request->date))
            {
                $date_range = explode(' - ', $request->date);
                $query->whereBetween('date', $date_range);
            }

            if(!empty($request->category))
            {
                $query->where('category', '=', $request->category);
            }
            $transactions = $query->get();

            return view('customer.transaction', compact('transactions', 'category'));
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }

    public function profile()
    {
        if(\Auth::user()->can('manage account'))
        {
            $userDetail              = \Auth::user();
            $userDetail->customField = CustomField::getData($userDetail, 'customer');
            $customFields            = CustomField::where('module', '=', 'customer')->get();

            return view('customer.profile', compact('userDetail', 'customFields'));
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }

    public function editprofile(Request $request)
    {
        if(\Auth::user()->can('edit account'))
        {
            $userDetail = \Auth::user();
            $user       = Customer::findOrFail($userDetail['id']);

            $this->validate(
                $request, [
                            'name' => 'required|max:120',
                            'contact' => 'required',
                            'email' => 'required|email|unique:users,email,' . $userDetail['id'],
                        ]
            );

            if($request->hasFile('profile'))
            {
                $filenameWithExt = $request->file('profile')->getClientOriginalName();
                $filename        = pathinfo($filenameWithExt, PATHINFO_FILENAME);
                $extension       = $request->file('profile')->getClientOriginalExtension();
                $fileNameToStore = $filename . '_' . time() . '.' . $extension;

                $dir        = storage_path('app/public/avatar/');
                $image_path = $dir . $userDetail['avatar'];

                if(File::exists($image_path))
                {
                    File::delete($image_path);
                }

                if(!file_exists($dir))
                {
                    mkdir($dir, 0777, true);
                }

                $path = $request->file('profile')->storeAs('public/avatar/', $fileNameToStore);

            }

            if(!empty($request->profile))
            {
                $user['avatar'] = $fileNameToStore;
            }
            $user['name']    = $request['name'];
            $user['email']   = $request['email'];
            $user['contact'] = $request['contact'];
            $user->save();
            CustomField::saveData($user, $request->customField);

            return redirect()->back()->with(
                'success', 'Profile successfully updated.'
            );
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }

    public function editBilling(Request $request)
    {
        if(\Auth::user()->can('edit account'))
        {
            $userDetail = \Auth::user();
            $user       = Customer::findOrFail($userDetail['id']);
            $this->validate(
                $request, [
                            'billing_name' => 'required',
                            'billing_country' => 'required',
                            'billing_state' => 'required',
                            'billing_city' => 'required',
                            'billing_phone' => 'required',
                            'billing_zip' => 'required',
                            'billing_address' => 'required',
                        ]
            );
            $input = $request->all();
            $user->fill($input)->save();

            return redirect()->back()->with(
                'success', 'Profile successfully updated.'
            );
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }

    public function editShipping(Request $request)
    {
        if(\Auth::user()->can('edit account'))
        {
            $userDetail = \Auth::user();
            $user       = Customer::findOrFail($userDetail['id']);
            $this->validate(
                $request, [
                            'shipping_name' => 'required',
                            'shipping_country' => 'required',
                            'shipping_state' => 'required',
                            'shipping_city' => 'required',
                            'shipping_phone' => 'required',
                            'shipping_zip' => 'required',
                            'shipping_address' => 'required',
                        ]
            );
            $input = $request->all();
            $user->fill($input)->save();

            return redirect()->back()->with(
                'success', 'Profile successfully updated.'
            );
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }
    }

    public function updatePassword(Request $request)
    {
        if(\Auth::user()->can('change password account'))
        {
            if(Auth::Check())
            {
                $request->validate(
                    [
                        'current_password' => 'required',
                        'new_password' => 'required|min:6',
                        'confirm_password' => 'required|same:new_password',
                    ]
                );
                $objUser          = Auth::user();
                $request_data     = $request->All();
                $current_password = $objUser->password;
                if(Hash::check($request_data['current_password'], $current_password))
                {
                    $user_id            = Auth::User()->id;
                    $obj_user           = Customer::find($user_id);
                    $obj_user->password = Hash::make($request_data['new_password']);;
                    $obj_user->save();

                    return redirect()->back()->with('success', __('Password updated successfully.'));
                }
                else
                {
                    return redirect()->back()->with('error', __('Please enter correct current password.'));
                }
            }
            else
            {
                return redirect()->back()->with('error', __('Something is wrong.'));
            }
        }
        else
        {
            return redirect()->back()->with('error', __('Permission denied.'));
        }

    }

    public function changeLanquage($lang)
    {
        if(\Auth::user()->can('manage language'))
        {
            $user       = Auth::user();
            $user->lang = $lang;
            $user->save();

            return redirect()->back()->with('success', __('Language Change Successfully!'));
        }
        else
        {
            return redirect()->back();
        }

    }
}
